jaraco.collections
==================

Models and classes to supplement the stdlib 'collections' module.

.. image:: https://img.shields.io/pypi/v/jaraco.collections.svg
   :target: https://pypi.io/project/jaraco.collections

.. image:: https://img.shields.io/pypi/pyversions/jaraco.collections.svg

.. image:: https://img.shields.io/pypi/dm/jaraco.collections.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.collections/master.svg
   :target: http://travis-ci.org/jaraco/jaraco.collections

RangeMap
--------

A dictionary-like object that maps a range of values to a given value.
